@@ -43,6 +43,13 @@ static char PyAptError_Doc[] =
 
 PyObject *PyAptError;
 
+static char PyAptWarning_Doc[] =
+   "Exception class for most python-apt warnings.\n"
+   "\n"
+   ".. versionadded:: 2.7";
+
+PyObject *PyAptWarning;
+
 static char PyAptCacheMismatchError_Doc[] =
    "Raised when passing an object from a different cache to\n"
    ":class:`apt_pkg.DepCache` methods\n\n"
@@ -811,6 +818,7 @@ static struct _PyAptPkgAPIStruct API = {
    &PyPackageManager_Type,    // packagemanager_type
    &PyPackageManager_FromCpp,   // packagemanager_type
    &PyPackageManager_ToCpp,   // packagemanager_type
+   &PyPackageManagerProgressFancy_Type,
    &PyPackageRecords_Type,    // packagerecords_type
    0,                         // FIXME: packagerecords_fromcpp
    0,                         // FIXME: packagerecords_tocpp
@@ -886,6 +894,9 @@ extern "C" void initapt_pkg()
    PyAptError = PyErr_NewExceptionWithDoc("apt_pkg.Error", PyAptError_Doc, PyExc_SystemError, NULL);
    if (PyAptError == NULL)
       INIT_ERROR;
+   PyAptWarning = PyErr_NewExceptionWithDoc("apt_pkg.Warning", PyAptWarning_Doc, PyExc_Warning, NULL);
+   if (PyAptWarning == NULL)
+      INIT_ERROR;
 
    PyAptCacheMismatchError = PyErr_NewExceptionWithDoc("apt_pkg.CacheMismatchError", PyAptCacheMismatchError_Doc, PyExc_ValueError, NULL);
    if (PyAptCacheMismatchError == NULL)
@@ -905,6 +916,7 @@ extern "C" void initapt_pkg()
    Config->NoDelete = true;
    PyModule_AddObject(Module,"config",Config);
    PyModule_AddObject(Module,"Error",PyAptError);
+   PyModule_AddObject(Module,"Warning",PyAptWarning);
    PyModule_AddObject(Module,"CacheMismatchError", PyAptCacheMismatchError);
 
 
@@ -948,6 +960,8 @@ extern "C" void initapt_pkg()
    /* ========================= pkgmanager.cc ========================= */
    ADDTYPE(Module,"_PackageManager",&PyPackageManager_Type);
    ADDTYPE(Module,"PackageManager",&PyPackageManager2_Type);
+   /* ========================= pkgmanagerprogress.cc ==================== */
+   ADDTYPE(Module,"PackageManagerProgressFancy",&PyPackageManagerProgressFancy_Type);
    /* ========================= pkgrecords.cc ========================= */
    ADDTYPE(Module,"PackageRecords",&PyPackageRecords_Type);
    /* ========================= pkgsrcrecords.cc ========================= */
